# Important note!
# There are at least two quite separate OCaml cairo projects.
#
# This is (packaged in Mageia >= 7):
#   https://forge.ocamlcore.org/projects/cairo/
#   https://github.com/Chris00/ocaml-cairo
#
# The other one (which used to be packaged in Mageia <= 6) is:
#   https://cairographics.org/cairo-ocaml/

%define rel 1
# "fix" underlinking:
%define _disable_ld_no_undefined 1


Name:           ocaml-cairo
Epoch:          2
Version:        0.6.5
Release:        %mkrel %{rel}

Summary:        OCaml library for accessing cairo graphics
Group:          Development/OCaml

License:        LGPLv3+
URL:            https://github.com/Chris00/%{name}

Source0:        %{url}/releases/download/%{version}/cairo2-%{version}.tbz
# Fix a segfault when a Cairo error occurs
# See https://github.com/Chris00/ocaml-cairo/issues/36
Patch0:         https://github.com/Chris00/ocaml-cairo/pull/37.patch

BuildRequires:  ocaml >= 4.03
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-dune-configurator-devel
BuildRequires:  ocaml-lablgtk2-devel
BuildRequires:  pkgconfig(cairo) >= 1.2.0
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gtk+-2.0)

%global _description %{expand:
Cairo is a multi-platform library providing anti-aliased vector-based
rendering for multiple target backends. Paths consist of line segments
and cubic splines and can be rendered at any width with various join
and cap styles. All colors may be specified with optional translucence
(opacity/alpha) and combined using the extended Porter/Duff
compositing algebra as found in the X Render Extension.

Cairo exports a stateful rendering API similar in spirit to the path
construction, text, and painting operators of PostScript, (with the
significant addition of translucence in the imaging model). When
complete, the API is intended to support the complete imaging model of
PDF 1.4.}

%description
%_description

This package contains OCaml bindings for Cairo.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       ocaml-lablgtk2-devel%{?_isa}
Requires:       pkgconfig(cairo)

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%package        gtk
Summary:        OCaml library to render cairo on a gtk2 canvas
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description    gtk
%_description

This package contains OCaml bindings for rendering cairo on a gtk2 canvas.


%package        gtk-devel
Summary:        Development files for %{name}-gtk
Requires:       %{name}-gtk%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}


%description    gtk-devel
The %{name}-gtk-devel package contains libraries and signature files for
developing applications that use %{name}-gtk.


%package        pango
Summary:        OCaml library to use pango with cairo
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description    pango
%_description

This package contains OCaml bindings to use pango with cairo.


%package        pango-devel
Summary:        Development files for %{name}-pango
Requires:       %{name}-pango%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}


%description    pango-devel
The %{name}-pango-devel package contains libraries and signature files
for developing applications that use %{name}-pango.


%prep
%autosetup -n cairo2-%{version} -p1


%build
cairo_cflags="$(pkgconf --cflags cairo)"
cairo_libs="$(pkgconf --libs cairo)"
gtk_cflags="$(pkgconf --cflags gtk+-2.0)"
gtk_libs="$(pkgconf --libs gtk+-2.0)"
export CAIRO_CFLAGS="%{build_cflags} $cairo_cflags"
export CAIRO_LIBS="%{build_ldflags} $cairo_libs"
export GTK_CFLAGS="%{build_cflags} $gtk_cflags"
export GTK_LIBS="%{build_ldflags} $gtk_libs"
%dune_build


%install
%dune_install -s


%check
%dune_check


%files -f .ofiles-cairo2
%doc CHANGES.md README.md
%license GPL3.md LICENSE.md


%files devel -f .ofiles-cairo2-devel
# XXX The tutorial doesn't build.
%doc examples


%files gtk -f .ofiles-cairo2-gtk


%files gtk-devel -f .ofiles-cairo2-gtk-devel


%files pango -f .ofiles-cairo2-pango


%files pango-devel -f .ofiles-cairo2-pango-devel



%changelog
* Thu Jun 19 2025 daviddavid <daviddavid> 2:0.6.5-1.mga10
+ Revision: 2192950
- new version: 0.6.5

* Thu Oct 20 2022 pterjan <pterjan> 2:0.6.4-1.mga9
+ Revision: 1898076
- Update to 0.6.4

* Thu May 19 2022 pterjan <pterjan> 2:0.6.2-3.mga9
+ Revision: 1859005
- Rebuild for OCaml 4.14

* Wed Apr 06 2022 umeabot <umeabot> 2:0.6.2-2.mga9
+ Revision: 1845912
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 2:0.6.2-1.mga9
+ Revision: 1750774
- Rebuild for ocaml-4.12
- Avoid a GC-related segfault
- Fix builds of consuming packages with -fno-common

* Wed Mar 03 2021 tv <tv> 2:0.6.1-5.mga9
+ Revision: 1696566
- Rebuild for ocaml-4.12
- Avoid a GC-related segfault
- Fix builds of consuming packages with -fno-common

* Sun Jan 10 2021 pterjan <pterjan> 2:0.6.1-4.mga8
+ Revision: 1670434
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 2:0.6.1-3.mga8
+ Revision: 1551481
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 2:0.6.1-2.mga8
+ Revision: 1544330
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 tv <tv> 2:0.6.1-1.mga8
+ Revision: 1482872
- New upstream version 0.6.1
- Add -gtk and -pango subpackages corresponding to upstream's opam packages
- Add -gtk-devel and -pango-devel subpackages to manage dependencies
- Add %%check script (disabled for now)

* Sun Jan 19 2020 tv <tv> 2:0.4.7-0.5.gitbe5a298.mga8
+ Revision: 1481548
- new release + rebuild for ocaml-4.10

* Wed Oct 24 2018 pterjan <pterjan> 2:0.4.7-0.4.gitbe5a298.mga7
+ Revision: 1325034
- Rebuild for ocaml 4.07.1

* Wed Oct 03 2018 pterjan <pterjan> 2:0.4.7-0.3.gitbe5a298.mga7
+ Revision: 1316328
- Mageia 7 Mass Rebuild

* Sun Nov 26 2017 tv <tv> 2:0.4.7-0.2.gitbe5a298.mga7
+ Revision: 1179953
- fix deps

* Sun Nov 26 2017 tv <tv> 2:0.4.7-0.1.gitbe5a298.mga7
+ Revision: 1179420
- switch to the other (buildable) cairo ocaml project
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 1.2.0.2-3.mga6
+ Revision: 1056264
- Rebuild for fix in ocaml

* Tue Feb 16 2016 umeabot <umeabot> 1.2.0.2-2.mga6
+ Revision: 961782
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 eatdirt <eatdirt> 1.2.0.2-1.mga6
+ Revision: 886272
- Upgrade to latest git HEAD 1.2.0.2

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0.1-13.mga5
+ Revision: 742339
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0.1-12.mga5
+ Revision: 682997
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.2.0.1-11.mga4
+ Revision: 523299
- Mageia 4 Mass Rebuild

* Sat Apr 06 2013 malo <malo> 1.2.0.1-10.mga3
+ Revision: 408604
- fix requires and buildrequires

* Sat Jan 12 2013 umeabot <umeabot> 1.2.0.1-9.mga3
+ Revision: 361181
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 02 2012 blue_prawn <blue_prawn> 1.2.0.1-8.mga3
+ Revision: 302046
- rebuild for new ocaml 4.00

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.2.0.1-7.mga3
+ Revision: 300045
- new rpm group for ocaml

* Sun Dec 04 2011 malo <malo> 1.2.0.1-6.mga2
+ Revision: 176184
- adding missing Require ocaml-lablgtk2-devel
- spec clean-up
- adding missing Requires ocaml-lablgtk2

* Sun Nov 06 2011 malo <malo> 1.2.0.1-5.mga2
+ Revision: 164430
- using mkrel for release
- imported package ocaml-cairo


* Mon Sep 19 2011 Alexandre Lissy <alissy@mandriva.com> 1.2.0.1-5
+ Revision: 700302
- Changing BuildRequires against ocaml-lablgtk2 to -devel
- Updating version
- Release bump
- Using tarball from git, not cvs
  Updating BuildRequires against ocaml-lablgtk2 instead of ocaml-lablgtk2-devel because of pango.cmo needed

* Thu Apr 22 2010 Florent Monnier <blue_prawn@mandriva.org> 1.2.0.cvs20080301-4.1mdv2011.0
+ Revision: 537991
- just a rebuild to fix the "inconsistent assumptions over interface" problem

* Sun Jun 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.2.0.cvs20080301-4mdv2010.0
+ Revision: 390235
- rebuild

* Sat Feb 21 2009 Florent Monnier <blue_prawn@mandriva.org> 1.2.0.cvs20080301-3mdv2009.1
+ Revision: 343706
- incremented rel number
- added version in the META file

* Tue Feb 03 2009 Florent Monnier <blue_prawn@mandriva.org> 1.2.0.cvs20080301-2mdv2009.1
+ Revision: 337135
- The initial RPM release was made from the fedora rpm .spec file (revision 1.7) by Richard W.M. Jones
- import ocaml-cairo


* Tue Dec 16 2008 Florent Monnier <fmonnier@linux-nantes.org> 1.2.0.cvs20080301-1mdv
- Initial RPM release made from the redhat rpm .spec file (revision 1.7) by Richard W.M. Jones
